==> fuioupay-sdk-1.0.0.20231012-20230926.115319-1-sources.jar: com/fshows/fuiou/enums/settlement/FuiouSettlementApiDefinitionEnum.java <==
package com.fshows.fuiou.enums.settlement;

import com.fshows.fuiou.client.base.IFuiouApiDefinition;
import com.fshows.fuiou.constant.FuiouConstant;
import com.fshows.fuiou.request.settlement.QuerySettlementListRequest;
import com.fshows.fuiou.request.trade.order.FuiouHisOrderQueryRequest;
import com.fshows.fuiou.request.trade.order.FuiouOrderCloseRequest;
import com.fshows.fuiou.request.trade.order.FuiouOrderQueryRequest;
import com.fshows.fuiou.request.trade.order.FuiouOrderRevokedRequest;
import com.fshows.fuiou.request.trade.order.FuiouRefundQueryRequest;
import com.fshows.fuiou.request.trade.order.FuiouRefundRequest;
import com.fshows.fuiou.request.trade.pay.FuiouJsApiPayRequest;
import com.fshows.fuiou.request.trade.pay.FuiouPreOrderRequest;
import com.fshows.fuiou.request.trade.pay.FuiouScanCardRequest;
import com.fshows.fuiou.request.trade.pay.FuiouWxAndUnionUserIdRequest;
import com.fshows.fuiou.response.settlement.QuerySettlementListResponse;
import com.fshows.fuiou.response.trade.order.FuiouOrderCloseResponse;
import com.fshows.fuiou.response.trade.order.FuiouOrderQueryResponse;
import com.fshows.fuiou.response.trade.order.FuiouOrderRevokedResponse;
import com.fshows.fuiou.response.trade.order.FuiouRefundQueryResponse;
import com.fshows.fuiou.response.trade.order.FuiouRefundResponse;
import com.fshows.fuiou.response.trade.pay.FuiouJsApiPayResponse;
import com.fshows.fuiou.response.trade.pay.FuiouPreOrderResponse;
import com.fshows.fuiou.response.trade.pay.FuiouScanCardResponse;
import com.fshows.fuiou.response.trade.pay.FuiouWxAndUnionUserIdResponse;

/**
 * 富友结算相关API
 *
 * @author liluqing
 * @version FuiouSettlementApiDefinitionEnum.java, v 0.1 2022-03-01 21:53 liluqing
 */
public enum FuiouSettlementApiDefinitionEnum implements IFuiouApiDefinition {
    QUERY_SETTLEMENT_LIST(
            "资金划拨查询，查询商户在某段时间内自动结算的笔数及金额信息",
            "/queryChnlPayAmt",
            FuiouConstant.SETTLEMENT_API_VERSION_V1,
            QuerySettlementListRequest.class,
            QuerySettlementListResponse.class
    )
    ;

    /**
     * 接口名称
     */
    private String name;
    /**
     * 接口uri子资源路径
     */
    private String apiSubURI;
    /**
     * 接口版本号
     */
    private String version;
    /**
     * 请求业务参数的Class类型
     */
    private Class requestClass;
    /**
     * 响应业务参数的Class类型
     */
    private Class responseClass;


    FuiouSettlementApiDefinitionEnum(String name,
                                     String apiSubURI,
                                     String version,
                                     Class requestClass,
                                     Class responseClass) {
        this.name = name;
        this.apiSubURI = apiSubURI;
        this.version = version;
        this.requestClass = requestClass;
        this.responseClass = responseClass;
    }

    @Override
    public String getApiSubURI() {
        return apiSubURI;
    }

    @Override
    public String getVersion() {
        return version;
    }

    @Override
    public Class getRequestClass() {
        return requestClass;
    }

    @Override
    public Class getResponseClass() {
        return responseClass;
    }
}

==> fuioupay-sdk-1.0.0.20231026-20231012.121211-1-sources.jar: com/fshows/fuiou/enums/settlement/FuiouSettlementApiDefinitionEnum.java <==
package com.fshows.fuiou.enums.settlement;

import com.fshows.fuiou.client.base.IFuiouApiDefinition;
import com.fshows.fuiou.constant.FuiouConstant;
import com.fshows.fuiou.request.settlement.FuiouQuerySettlementListRequest;
import com.fshows.fuiou.response.settlement.FuiouQuerySettlementListResponse;

/**
 * 富友结算相关API
 *
 * @author liluqing
 * @version FuiouSettlementApiDefinitionEnum.java, v 0.1 2022-03-01 21:53 liluqing
 */
public enum FuiouSettlementApiDefinitionEnum implements IFuiouApiDefinition {
    QUERY_SETTLEMENT_LIST(
            "资金划拨查询，查询商户在某段时间内自动结算的笔数及金额信息",
            "/queryChnlPayAmt",
            FuiouConstant.SETTLEMENT_API_VERSION_V1,
            FuiouQuerySettlementListRequest.class,
            FuiouQuerySettlementListResponse.class
    )
    ;

    /**
     * 接口名称
     */
    private String name;
    /**
     * 接口uri子资源路径
     */
    private String apiSubURI;
    /**
     * 接口版本号
     */
    private String version;
    /**
     * 请求业务参数的Class类型
     */
    private Class requestClass;
    /**
     * 响应业务参数的Class类型
     */
    private Class responseClass;


    FuiouSettlementApiDefinitionEnum(String name,
                                     String apiSubURI,
                                     String version,
                                     Class requestClass,
                                     Class responseClass) {
        this.name = name;
        this.apiSubURI = apiSubURI;
        this.version = version;
        this.requestClass = requestClass;
        this.responseClass = responseClass;
    }

    @Override
    public String getApiSubURI() {
        return apiSubURI;
    }

    @Override
    public String getVersion() {
        return version;
    }

    @Override
    public Class getRequestClass() {
        return requestClass;
    }

    @Override
    public Class getResponseClass() {
        return responseClass;
    }
}
